@@ -36,9 +36,9 @@ void mmc_erase(struct burn_drive *, int);
 void mmc_read_toc(struct burn_drive *);
 void mmc_read_disc_info(struct burn_drive *);
 void mmc_read_atip(struct burn_drive *);
-void mmc_read_sectors(struct burn_drive *,
-		      int,
-		      int, const struct burn_read_opts *, struct buffer *);
+int mmc_read_cd(struct burn_drive *d, int start, int len,
+                int sec_type, int main_ch,
+                const struct burn_read_opts *o, struct buffer *buf, int flag);
 void mmc_set_speed(struct burn_drive *, int, int);
 void mmc_read_lead_in(struct burn_drive *, struct buffer *);
 void mmc_perform_opc(struct burn_drive *);
@@ -128,4 +128,11 @@ int mmc_get_leadin_text(struct burn_drive *d,
                         unsigned char **text_packs, int *num_packs, int flag);
 
 
+#ifdef Libburn_develop_quality_scaN
+/* B21108 ts */
+int mmc_nec_optiarc_f3(struct burn_drive *d, int sub_op,
+                       int start_lba, int rate_period,
+                       int *eba, int *error_rate1, int *error_rate2);
+#endif
+
 #endif /*__MMC*/
