@@ -28,7 +28,6 @@ struct isoburn_toc_entry {
  int track_no; /* point */
  int start_lba;
  int track_blocks;
-
  char *volid; /* For caching a volume id from emulated toc on overwriteables */
 
  struct isoburn_toc_entry *next;
@@ -165,6 +164,9 @@ struct isoburn {
  void *msgs_submit_handle;  /* specific to application method */
  int msgs_submit_flag;      /* specific to application method */
 
+ /* Forwarding an image generation option to the burn wrapper */
+ int do_tao;
+ 
 };
 
 
@@ -393,6 +395,8 @@ struct isoburn_imgen_opts {
     unsigned int rockridge :1;
     unsigned int joliet :1;
     unsigned int iso1999 :1;
+    unsigned int hfsplus :1;
+    unsigned int fat :1;
 
     /* Whether to mark suitable IsoNode as hardlinks in RRIP PX */
     unsigned int hardlinks :1;
@@ -662,6 +666,10 @@ struct isoburn_imgen_opts {
     */
     uint32_t tail_blocks;
 
+    /* Disk file paths of content of PreP partition and EFI system partition */
+    char *prep_partition;
+    char *efi_boot_partition;
+
     /* Eventual disk file paths of prepared images which shall be appended
        after the ISO image and described by partiton table entries in a MBR.
     */
@@ -671,6 +679,27 @@ struct isoburn_imgen_opts {
     /* Eventual name of the non-ISO aspect of the image. E.g. SUN ASCII label.
      */
     char ascii_disc_label[Libisoburn_disc_label_sizE];
+
+    /* HFS+ image serial number.
+     * 00...00 means that it shall be generated by libisofs.
+     */
+    uint8_t hfsp_serial_number[8];
+
+    /* Allocation block size of HFS+ : 0= auto , 512, or 2048
+     */
+    int hfsp_block_size;
+
+    /* Block size of and in APM : 0= auto , 512, or 2048
+     */
+    int apm_block_size;
+
+    /* Write mode for optical media:
+     *   0 = auto
+     *   1 = TAO, Incremental, no RESERVE TRACK
+     *  -1 = SAO, DAO, RESERVE TRACK
+     */
+    int do_tao;
+
 };
 
 
@@ -738,6 +767,7 @@ struct isoburn_toc_disc {
  struct isoburn_toc_track *tracks;               /* storage array */
  struct isoburn_toc_track **track_pointers;      /* storage array */
  int session_count;
+ int incomplete_session_count;
  int track_count;
  struct isoburn_toc_entry *toc;
 };
