@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2007 Vreixo Formoso
- * Copyright (c) 2010 Thomas Schmitt
+ * Copyright (c) 2010 - 2013 Thomas Schmitt
  *
  * This file is part of the libisofs project; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License version 2 
@@ -160,7 +160,13 @@ int el_torito_get_selection_crit(ElToritoBootImage *bootimg, uint8_t crit[20])
 /* API */
 int el_torito_seems_boot_info_table(ElToritoBootImage *bootimg, int flag)
 {
-    return bootimg->seems_boot_info_table;
+    switch (flag & 15) {
+    case 0:
+        return bootimg->seems_boot_info_table;
+    case 1:
+        return bootimg->seems_grub2_boot_info;
+    }
+    return 0;
 }
 
 /**
@@ -197,14 +203,14 @@ void el_torito_patch_isolinux_image(ElToritoBootImage *bootimg)
  */
 int el_torito_set_isolinux_options(ElToritoBootImage *bootimg, int options, int flag)
 {
-    bootimg->isolinux_options = (options & 0x03);
+    bootimg->isolinux_options = (options & 0x03ff);
     return ISO_SUCCESS;
 }
 
 /* API */
 int el_torito_get_isolinux_options(ElToritoBootImage *bootimg, int flag)
 {
-    return bootimg->isolinux_options & 0x03;
+    return bootimg->isolinux_options & 0x03ff;
 }
 
 /* API */
@@ -1032,7 +1038,7 @@ int el_torito_catalog_file_src_create(Ecma119Image *target, IsoFileSrc **src)
     }
 
     /* fill fields */
-    file->prev_img = 0; /* TODO allow copy of old img catalog???? */
+    file->no_write = 0; /* TODO allow copy of old img catalog???? */
     file->checksum_index = 0;
     file->nsections = 1;
     file->sections = calloc(1, sizeof(struct iso_file_section));
@@ -1096,13 +1102,14 @@ int make_boot_info_table(uint8_t *buf, uint32_t pvd_lba,
 }
 
 /**
- * Patch an isolinux boot image.
+ * Patch an El Torito boot image by a boot info table.
  *
  * @return
  *      1 on success, 0 error (but continue), < 0 error
  */
 static
-int patch_boot_image(uint8_t *buf, Ecma119Image *t, size_t imgsize, int idx)
+int patch_boot_info_table(uint8_t *buf, Ecma119Image *t,
+                               size_t imgsize, int idx)
 {
     int ret;
 
@@ -1116,29 +1123,41 @@ int patch_boot_image(uint8_t *buf, Ecma119Image *t, size_t imgsize, int idx)
     return ret;
 }
 
+
+/**
+ * Patch a GRUB2 El Torito boot image.
+ */
 static
-int eltorito_writer_compute_data_blocks(IsoImageWriter *writer)
+int patch_grub2_boot_image(uint8_t *buf, Ecma119Image *t,
+                           size_t imgsize, int idx,
+                           size_t pos, int offst)
+{
+    uint64_t blk;
+
+    if (imgsize < pos + 8)
+        return iso_msg_submit(t->image->id, ISO_ISOLINUX_CANT_PATCH, 0,
+                     "Isolinux image too small for GRUB2. Will not patch it.");
+    blk = ((uint64_t) t->bootsrc[idx]->sections[0].block) * 4 + offst;
+    iso_lsb((buf + pos), blk & 0xffffffff, 4);
+    iso_lsb((buf + pos + 4), blk >> 32, 4);
+    return ISO_SUCCESS;
+}
+
+
+/* Patch the boot images if indicated */
+int iso_patch_eltoritos(Ecma119Image *t)
 {
-    /*
-     * We have nothing to write, but if we need to patch an isolinux image,
-     * this is a good place to do so.
-     */
-    Ecma119Image *t;
     int ret, idx;
     size_t size;
     uint8_t *buf;
     IsoStream *new = NULL;
     IsoStream *original = NULL;
 
-    if (writer == NULL) {
-        return ISO_NULL_POINTER;
-    }
+    if (t->catalog == NULL)
+        return ISO_SUCCESS;
 
-    t = writer->target;
-
-    /* Patch the boot image info tables if indicated */
     for (idx = 0; idx < t->catalog->num_bootimages; idx++) {
-        if (!(t->catalog->bootimages[idx]->isolinux_options & 0x01))
+        if (!(t->catalog->bootimages[idx]->isolinux_options & 0x201))
     continue;
         original = t->bootsrc[idx]->stream;
         size = (size_t) iso_stream_get_size(original);
@@ -1162,9 +1181,20 @@ int eltorito_writer_compute_data_blocks(IsoImageWriter *writer)
         }
 
         /* ok, patch the read buffer */
-        ret = patch_boot_image(buf, t, size, idx);
-        if (ret < 0) {
-            return ret;
+        if (t->catalog->bootimages[idx]->isolinux_options & 0x200) {
+            /* GRUB2 boot provisions */
+            ret = patch_grub2_boot_image(buf, t, size, idx,
+                                         Libisofs_grub2_elto_patch_poS,
+                                         Libisofs_grub2_elto_patch_offsT);
+            if (ret < 0)
+                return ret;
+	}
+        /* Must be done as last patching */
+        if (t->catalog->bootimages[idx]->isolinux_options & 0x01) {
+            /* Boot Info Table */
+            ret = patch_boot_info_table(buf, t, size, idx);
+            if (ret < 0)
+                return ret;
         }
 
         /* replace the original stream with a memory stream that reads from
@@ -1179,6 +1209,16 @@ int eltorito_writer_compute_data_blocks(IsoImageWriter *writer)
     return ISO_SUCCESS;
 }
 
+static
+int eltorito_writer_compute_data_blocks(IsoImageWriter *writer)
+{
+    /*
+     * We have nothing to write.
+     */
+    return ISO_SUCCESS;
+}
+
+
 /**
  * Write the Boot Record Volume Descriptor (ECMA-119, 8.2)
  */
@@ -1221,7 +1261,7 @@ int eltorito_writer_free_data(IsoImageWriter *writer)
 
 int eltorito_writer_create(Ecma119Image *target)
 {
-    int ret, idx;
+    int ret, idx, outsource_efi = 0;
     IsoImageWriter *writer;
     IsoFile *bootimg;
     IsoFileSrc *src;
@@ -1253,6 +1293,9 @@ int eltorito_writer_create(Ecma119Image *target)
         }
     }
 
+    if (target->efi_boot_partition != NULL)
+        if (strcmp(target->efi_boot_partition, "--efi-boot-image") == 0)
+            outsource_efi = 1;
     for (idx = 0; idx < target->catalog->num_bootimages; idx++) {
         bootimg = target->catalog->bootimages[idx]->image;
         ret = iso_file_src_create(target, bootimg, &src);
@@ -1263,12 +1306,35 @@ int eltorito_writer_create(Ecma119Image *target)
 
         /* For patching an image, it needs to be copied always */
         if (target->catalog->bootimages[idx]->isolinux_options & 0x01) {
-            src->prev_img = 0;
+            src->no_write = 0;
+        }
+
+        /* If desired: Recognize first EFI boot image that will be newly
+           written, and mark it as claimed for being a partition.
+        */
+        if (outsource_efi &&
+            target->catalog->bootimages[idx]->platform_id == 0xef &&
+            src->no_write == 0) {
+           target->efi_boot_part_filesrc = src;
+           src->sections[0].block = 0xfffffffe;
+           ((IsoNode *) bootimg)->hidden |=
+                                   LIBISO_HIDE_ON_HFSPLUS | LIBISO_HIDE_ON_FAT;
+           outsource_efi = 0;
         }
     }
 
     /* we need the bootable volume descriptor */
     target->curblock++;
+
+    if (outsource_efi) {
+        /* Disable EFI Boot partition and complain */
+        free(target->efi_boot_partition);
+        target->efi_boot_partition = NULL;
+        iso_msg_submit(target->image->id, ISO_BOOT_NO_EFI_ELTO, 0,
+"No newly added El Torito EFI boot image found for exposure as GPT partition");
+        return ISO_BOOT_NO_EFI_ELTO;
+    }
+
     return ISO_SUCCESS;
 }
 
