@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2007 Vreixo Formoso
- * Copyright (c) 2009 - 2012 Thomas Schmitt
+ * Copyright (c) 2009 - 2013 Thomas Schmitt
  *
  * This file is part of the libisofs project; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License version 2 
@@ -78,11 +78,13 @@ int iso_image_new(const char *name, IsoImage **image)
         img->volset_id = strdup(name);
         img->volume_id = strdup(name);
     }
+    memset(img->application_use, 0, 512);
     img->system_area_data = NULL;
     img->system_area_options = 0;
     img->num_mips_boot_files = 0;
     for (i = 0; i < 15; i++)
          img->mips_boot_file_paths[i] = NULL;
+    img->sparc_core_node = NULL;
     img->builder_ignore_acl = 1;
     img->builder_ignore_ea = 1;
     img->inode_counter = 0;
@@ -136,6 +138,8 @@ void iso_image_unref(IsoImage *image)
         iso_filesystem_unref(image->fs);
         el_torito_boot_catalog_free(image->bootcat);
         iso_image_give_up_mips_boot(image, 0);
+        if (image->sparc_core_node != NULL)
+            iso_node_unref((IsoNode *) image->sparc_core_node);
         free(image->volset_id);
         free(image->volume_id);
         free(image->publisher_id);
@@ -145,6 +149,10 @@ void iso_image_unref(IsoImage *image)
         free(image->copyright_file_id);
         free(image->abstract_file_id);
         free(image->biblio_file_id);
+        free(image->creation_time);
+        free(image->modification_time);
+        free(image->expiration_time);
+        free(image->effective_time);
         if (image->used_inodes != NULL)
             free(image->used_inodes);
         if (image->system_area_data != NULL)
@@ -335,6 +343,50 @@ const char *iso_image_get_biblio_file_id(const IsoImage *image)
     return image->biblio_file_id;
 }
 
+int iso_image_set_pvd_times(IsoImage *image,
+                            char *creation_time, char *modification_time,
+                            char *expiration_time, char *effective_time)
+{
+    if (creation_time == NULL || modification_time == NULL ||
+        expiration_time == NULL || effective_time == NULL)
+        return ISO_NULL_POINTER;
+    image->creation_time = strdup(creation_time);
+    image->modification_time = strdup(modification_time);
+    image->expiration_time = strdup(expiration_time);
+    image->effective_time = strdup(effective_time);
+    if (image->creation_time == NULL || image->modification_time == NULL ||
+        image->expiration_time == NULL || image->effective_time == NULL)
+        return ISO_OUT_OF_MEM;
+    return ISO_SUCCESS;
+}
+
+int iso_image_get_pvd_times(IsoImage *image,
+                            char **creation_time, char **modification_time,
+                            char **expiration_time, char **effective_time)
+{
+    if (image->creation_time == NULL || image->modification_time == NULL ||
+        image->expiration_time == NULL || image->effective_time == NULL)
+        return ISO_NULL_POINTER;
+    *creation_time = image->creation_time;
+    *modification_time = image->modification_time;
+    *expiration_time = image->expiration_time;
+    *effective_time = image->effective_time;
+    return ISO_SUCCESS;
+}
+
+void iso_image_set_app_use(IsoImage *image, const char *app_use_data,
+                           int count)
+{
+    if (count < 0)
+        count= 0;
+    else if(count > 512)
+        count= 512;
+    if (count > 0)
+        memcpy(image->application_use, app_use_data, count);
+    if (count < 512)
+        memset(image->application_use + count, 0, 512 - count);
+}
+
 int iso_image_get_msg_id(IsoImage *image)
 {
     return image->id;
@@ -354,6 +406,14 @@ static
 int dir_update_size(IsoImage *image, IsoDir *dir)
 {
     IsoNode *pos;
+
+#ifdef Libisofs_update_sizes_abortablE
+    char *path= NULL;
+    IsoStream *base_stream;
+    int cancel_ret, ret;
+    uint32_t lba;
+#endif
+
     pos = dir->children;
     while (pos) {
         int ret = 1;
@@ -362,13 +422,51 @@ int dir_update_size(IsoImage *image, IsoDir *dir)
         } else if (pos->type == LIBISO_DIR) {
             /* recurse */
             ret = dir_update_size(image, ISO_DIR(pos));
+
+#ifdef Libisofs_update_sizes_abortablE
+            if (ret == ISO_CANCELED)
+                return ret; /* Message already issued by dir_update_size */
+#endif
+
         }
+
+#ifdef Libisofs_update_sizes_abortablE
+
+        /* This would report error and abort according to severity threshold.
+           But it is desirable to let the update_size crawler continue
+           its work after e.g. a file has vanished from hard disk.
+           So normally this macro case should be disabled.
+        */
+
         if (ret < 0) {
-            ret = iso_msg_submit(image->id, ret, 0, NULL);
-            if (ret < 0) {
-                return ret; /* cancel due error threshold */
+            cancel_ret = iso_msg_submit(image->id, ret, 0, NULL);
+            path = iso_tree_get_node_path(pos);
+            if (path != NULL) {
+                iso_msg_submit(image->id, ret, 0,
+                               "ISO path  : %s", path);
+                free(path);
             }
+            /* Report source path with streams which do not come from
+               the loaded ISO filesystem */
+            if (pos->type == LIBISO_FILE &&
+                iso_node_get_old_image_lba(pos, &lba, 0) == 0) {
+                base_stream = iso_stream_get_input_stream(
+                                                     ISO_FILE(pos)->stream, 1);
+                if (base_stream == NULL)
+                    base_stream = ISO_FILE(pos)->stream;
+                path = iso_stream_get_source_path(base_stream, 0);
+                if (path != NULL) {
+                    iso_msg_submit(image->id, ret, 0,
+                                   "Local path: %s", path);
+                    free(path);
+                }
+            }
+            if (cancel_ret < 0)
+                return cancel_ret; /* cancel due error threshold */
         }
+
+#endif /* Libisofs_update_sizes_abortablE */
+
         pos = pos->next;
     }
     return ISO_SUCCESS;
@@ -732,3 +830,24 @@ int iso_image_hfsplus_get_blessed(IsoImage *img, IsoNode ***blessed_nodes,
     return 1;
 }
 
+
+/* API */
+int iso_image_set_sparc_core(IsoImage *img, IsoFile *sparc_core, int flag)
+{
+    if (img->sparc_core_node != NULL)
+        iso_node_unref((IsoNode *) img->sparc_core_node);
+    img->sparc_core_node = sparc_core;
+    if (sparc_core != NULL)
+        iso_node_ref((IsoNode *) sparc_core);
+    return 1;
+}
+
+
+/* API */
+int iso_image_get_sparc_core(IsoImage *img, IsoFile **sparc_core, int flag)
+{
+    *sparc_core = img->sparc_core_node;
+    return 1;
+}
+
+
