@@ -19,6 +19,7 @@
 #include "aaip_0_2.h"
 #include "messages.h"
 #include "util.h"
+#include "eltorito.h"
 
 
 #include <stdlib.h>
@@ -54,6 +55,8 @@ void iso_node_ref(IsoNode *node)
  */
 void iso_node_unref(IsoNode *node)
 {
+    if (node == NULL)
+        return;
     if (--node->refcount == 0) {
         switch (node->type) {
         case LIBISO_DIR:
@@ -78,6 +81,14 @@ void iso_node_unref(IsoNode *node)
                 IsoSymlink *link = (IsoSymlink*) node;
                 free(link->dest);
             }
+            break;
+        case LIBISO_BOOT:
+            {
+                IsoBoot *bootcat = (IsoBoot *) node;
+                if (bootcat->content != NULL)
+                    free(bootcat->content);
+            }
+            break;
         default:
             /* other kind of nodes does not need to delete anything here */
             break;
@@ -1615,6 +1626,8 @@ int iso_aa_lookup_attr(unsigned char *aa_string, char *name,
 
     ret = iso_aa_get_attrs(aa_string, &num_attrs, &names,
                            &value_lengths, &values, 0);
+    if (ret < 0)
+        return ret;
     for (i = 0; i < (int) num_attrs; i++) {
         if (strcmp(names[i], name))
     continue;
@@ -1714,6 +1727,7 @@ int attr_enlarge_list(char ***names, size_t **value_lengths, char ***values,
                         bit2= delete the given names rather than overwrite
                               their content
                         bit4= do not overwrite value of empty name
+                        bit5= do not overwrite isofs attributes 
                         bit15= release memory and return 1
 */
 static
@@ -1762,6 +1776,8 @@ int iso_node_merge_xattr(IsoNode *node, size_t num_attrs, char **names,
             continue;
         if (names[i][0] == 0 && (flag & 16))
             continue;
+        if ((flag & 32) && strncmp(names[i], "isofs.", 6) == 0)
+            continue;
         for (j = 0; j < *m_num_attrs; j++) {
             if ((*m_names)[j] == NULL)
                 continue;
@@ -1807,6 +1823,8 @@ int iso_node_merge_xattr(IsoNode *node, size_t num_attrs, char **names,
                 continue;
             if (names[i][0] == 0 && (flag & 16))
                 continue;
+            if ((flag & 32) && strncmp(names[i], "isofs.", 6) == 0)
+                continue;
             for (j = 0; j < *m_num_attrs; j++) {
                 if ((*m_names)[j] == NULL)
                     continue;
@@ -1857,13 +1875,13 @@ int iso_node_set_attrs(IsoNode *node, size_t num_attrs, char **names,
         for (i = 0; i < num_attrs; i++)
             if (strncmp(names[i], "user.", 5) != 0 && names[i][0] != 0) 
                 return ISO_AAIP_NON_USER_NAME;  
-
-    if ((flag & (2 | 4)) || !(flag & 8)) {
+    if ((flag & (2 | 4 | 16)) || !(flag & 8)) {
         /* Merge old and new lists */
         ret = iso_node_merge_xattr(
                   node, num_attrs, names, value_lengths, values,
                   &m_num, &m_names, &m_value_lengths, &m_values,
-                  (flag & 4) | (!(flag & 2)) | ((!(flag & 1)) << 4));
+                  (flag & 4) | (!(flag & 2)) | ((!(flag & 1)) << 4) |
+                  ((flag & 16) << 1));
         if (ret < 0)
             goto ex;
         num_attrs = m_num;
@@ -2138,10 +2156,12 @@ int iso_node_set_acl_text(IsoNode *node, char *access_text, char *default_text,
                 ret = aaip_encode_both_acl(access_text, default_text, st_mode,
                                            &acl_len, &acl, 2 | 8);
         }
-        if (ret <= 0) {
+        if (ret == -1)
             ret = ISO_OUT_OF_MEM;
+        else if (ret <= 0 && ret >= -3)
+            ret = ISO_AAIP_BAD_ACL_TEXT;
+        if (ret <= 0)
             goto ex;
-        }
 
         if(acl == NULL) { /* Delete whole ACL attribute */
             /* Update S_IRWXG by eventual "group::" ACL entry.
@@ -2194,6 +2214,8 @@ int iso_node_set_acl_text(IsoNode *node, char *access_text, char *default_text,
     }
     ret = aaip_encode_both_acl(access_text, default_text,
                                st_mode, &acl_len, &acl, 2 | 8);
+    if (ret < -3)
+        goto ex;
     if (ret <= 0) {
         ret = ISO_AAIP_BAD_ACL_TEXT;
         goto ex;
