@@ -232,6 +232,10 @@ void iso_lsb(uint8_t *buf, uint32_t num, int bytes);
 void iso_msb(uint8_t *buf, uint32_t num, int bytes);
 void iso_bb(uint8_t *buf, uint32_t num, int bytes);
 
+/* An alternative to iso_lsb() which advances the write pointer
+*/
+int iso_lsb_to_buf(char **wpt, uint32_t value, int bytes, int flag);
+
 uint32_t iso_read_lsb(const uint8_t *buf, int bytes);
 uint32_t iso_read_msb(const uint8_t *buf, int bytes);
 
@@ -543,6 +547,12 @@ int checksum_md5_xinfo_func(void *data, int flag);
  */
 int checksum_md5_xinfo_cloner(void *old_data, void **new_data, int flag);
 
+/* The iso_node_xinfo_cloner function which gets associated to
+ * iso_hfsplus_xinfo_func by iso_init() resp. iso_init_with_flag() via
+ * iso_node_xinfo_make_clonable()
+ */
+int iso_hfsplus_xinfo_cloner(void *old_data, void **new_data, int flag);
+
 
 /* ------------------------------------------------------------------------- */
 
@@ -567,4 +577,12 @@ void *iso_alloc_mem(size_t size, size_t count, int flag);
         }
 
 
+/* ------------------------------------------------------------------------- */
+
+
+/* To avoid the need to include more system header files */
+uint16_t iso_ntohs(uint16_t v);
+uint16_t iso_htons(uint16_t v);
+
+
 #endif /*LIBISO_UTIL_H_*/
