@@ -1,7 +1,7 @@
 
 /* xorriso - creates, loads, manipulates and burns ISO 9660 filesystem images.
 
-   Copyright 2007-2012 Thomas Schmitt, <scdbackup@gmx.net>
+   Copyright 2007-2013 Thomas Schmitt, <scdbackup@gmx.net>
 
    Provided under GPL version 2 or later.
 
@@ -347,6 +347,21 @@ int Xorriso_option_application_id(struct XorrisO *xorriso, char *name,
 }
 
 
+/* Command -application_use */
+int Xorriso_option_application_use(struct XorrisO *xorriso, char *path,
+                                   int flag)
+{
+ if(Sfile_str(xorriso->application_use, path, 0) <= 0) {
+   sprintf(xorriso->info_text,
+           "-application_use: parameter string is much too long (%d)",
+           (int) strlen(path));
+   Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FAILURE", 0);
+   return(0);
+ }
+ return(1);
+}
+
+
 /* Option -as */
 /* @param flag bit0=do not report the added item
                bit1=do not reset pacifier, no final pacifier message
@@ -615,6 +630,8 @@ unusable_size:;
    if(size <= 0)
      goto unusable_size;
    mode_flag= 3;
+ } else if(strcmp(mode, "without_spare") == 0 && (flag & 1)) {
+   mode_flag= 32;
  } else {
    sprintf(xorriso->info_text,
            "%s: Unknown %s mode '%s'",
@@ -630,7 +647,7 @@ unusable_size:;
  if(as_needed)
    ret= Xorriso_blank_as_needed(xorriso, (flag&1)<<2);
  else if(flag&1)
-   ret= Xorriso_format_media(xorriso, size, mode_flag & 0xff83);
+   ret= Xorriso_format_media(xorriso, size, mode_flag & 0xffa7);
  else
    ret= Xorriso_blank_media(xorriso, mode_flag&3);
  if(ret==0)
@@ -1207,8 +1224,10 @@ int Xorriso_option_cdi(struct XorrisO *xorriso, char *iso_rr_path, int flag)
  Xorriso_warn_of_wildcards(xorriso, iso_rr_path, 1);
  sprintf(xorriso->info_text,"previous working directory:\n");
  Xorriso_info(xorriso,0);
- Text_shellsafe(xorriso->wdi, xorriso->result_line, 0);
- strcat(xorriso->result_line, "/\n");
+ Xorriso_esc_filepath(xorriso, xorriso->wdi, xorriso->result_line, 0);
+ if(xorriso->sh_style_result == 0 || xorriso->wdi[0] == 0)
+   strcat(xorriso->result_line, "/");
+ strcat(xorriso->result_line, "\n");
  Xorriso_result(xorriso,0);
  if(strcmp(iso_rr_path,"/")==0 || iso_rr_path[0]==0) {
    strcpy(xorriso->wdi,"");
@@ -1268,8 +1287,10 @@ int Xorriso_option_cdx(struct XorrisO *xorriso, char *disk_path, int flag)
  Xorriso_warn_of_wildcards(xorriso, disk_path, 1|2);
  sprintf(xorriso->info_text,"previous working directory on hard disk:\n");
  Xorriso_info(xorriso,0);
- Text_shellsafe(xorriso->wdx, xorriso->result_line, 0);
- strcat(xorriso->result_line, "/\n");
+ Xorriso_esc_filepath(xorriso, xorriso->wdx, xorriso->result_line, 0);
+ if(xorriso->sh_style_result == 0 || xorriso->wdx[0] == 0)
+   strcat(xorriso->result_line, "/");
+ strcat(xorriso->result_line, "\n");
  Xorriso_result(xorriso,0);
  if(strcmp(disk_path,"/")==0) {
    strcpy(xorriso->wdx,"");
