@@ -2,7 +2,7 @@
 
 /* xorriso - creates, loads, manipulates and burns ISO 9660 filesystem images.
 
-   Copyright 2007-2011 Thomas Schmitt, <scdbackup@gmx.net>
+   Copyright 2007-2012 Thomas Schmitt, <scdbackup@gmx.net>
 
    Provided under GPL version 2 or later.
 
@@ -194,7 +194,7 @@ int Xorriso_restore_is_identical(struct XorrisO *xorriso, void *in_node,
  int dummy;
 
  memset(type_text, 0, 5);
- if(!xorriso->volset_change_pending)
+ if(!Xorriso_change_is_pending(xorriso, 0))
    return(0);
  if(flag&1) {
    node= (IsoNode *) in_node;
@@ -596,7 +596,7 @@ int Xorriso_tree_restore_node(struct XorrisO *xorriso, IsoNode *node,
           xorriso->pacifier_byte_count - last_p_count >= 128*1024) {
          Xorriso_pacifier_callback(xorriso, "files restored",
                              xorriso->pacifier_count,
-                             xorriso->pacifier_total, "", 2|4);
+                             xorriso->pacifier_total, "", 2 | 4 | 8);
          last_p_count= xorriso->pacifier_byte_count;
        }
      }
@@ -1044,7 +1044,7 @@ went_well:;
  if(!(flag&2))
    Xorriso_pacifier_callback(xorriso, "files restored",
                              xorriso->pacifier_count,
-                             xorriso->pacifier_total, "", 4);
+                             xorriso->pacifier_total, "", 4 | 8);
  ret= 1;
 ex:;
  if(split_parts!=NULL) 
