@@ -1,7 +1,7 @@
 
 /* xorriso - creates, loads, manipulates and burns ISO 9660 filesystem images.
 
-   Copyright 2007-2010 Thomas Schmitt, <scdbackup@gmx.net>
+   Copyright 2007-2012 Thomas Schmitt, <scdbackup@gmx.net>
 
    Provided under GPL version 2 or later.
 
@@ -42,7 +42,10 @@ int Sfile_add_to_path(char path[SfileadrL], char *addon, int flag);
 int Sfile_scale(double value, char *result, int siz, double thresh, int flag);
   
 int Sfile_destroy_argv(int *argc, char ***argv, int flag);
-  
+
+int Sfile_count_char(char *text, char to_count);
+
+ 
 /*
  bit0= do not ignore trailing slash
  bit1= do not ignore empty components (other than the empty root name)
@@ -93,6 +96,8 @@ int Sfile_argv_bsl(int argc, char ***argv, int flag);
 */
 int Sfile_make_argv(char *progname, char *line, int *argc, char ***argv,
                     int flag);
+int Sfile_sep_make_argv(char *progname, char *line, char *separators,
+                        int max_argc, int *argc, char ***argv, int flag);
 
 /* YYMMDD[.hhmm[ss]] */
 int Sfile_decode_datestr(struct tm *reply, char *text, int flag);
